==> rel_to_abs-8.x-0.1.tar.gz: rel_to_abs/src/Plugin/Filter/RelToAbs.php <==
<?php

/**
 * @file
 * Contains \Drupal\rel_to_abs\Plugin\Filter\RelToAbs.
 */

namespace Drupal\rel_to_abs\Plugin\Filter;

use Drupal\filter\FilterProcessResult;
use Drupal\filter\Plugin\FilterBase;

/**
 * Provides a filter to convert relative paths to absolute URLs.
 *
 * @Filter(
 *   id = "rel_to_abs",
 *   title = @Translation("Convert relative paths to absolute URLs"),
 *   type = Drupal\filter\Plugin\FilterInterface::TYPE_TRANSFORM_REVERSIBLE
 * )
 */
class RelToAbs extends FilterBase {

  /**
   * {@inheritdoc}
   */
  public function process($text, $langcode) {

    $base_url = \Drupal::url('<front>', array(), array(
      'absolute' => TRUE,
      'language' => \Drupal::getContainer()
        ->get('language_manager')
        ->getLanguage($langcode)
    ));

    $text = $this->absoluteUrl($text, $base_url);
    return new FilterProcessResult($text);

  }

  /**
   * Absolute url callback.
   *
   * @param string $txt
   *   Text to be parsed.
   * @param string $base_url
   *   Base url of the site to prefix.
   *
   * @return string
   *   Processed text.
   */
  public function absoluteUrl($txt, $base_url) {
    $needles = array('href="', 'src="', 'background="');
    $new_txt = '';
    if (substr($base_url, -1) != '/') {
      $base_url .= '/';
    }
    $new_base_url = $base_url;

    foreach ($needles as $needle) {
      while ($pos = strpos($txt, $needle)) {
        $pos += strlen($needle);
        if (substr($txt, $pos, 7) != 'http://' && substr($txt, $pos, 8) != 'https://' && substr($txt, $pos, 6) != 'ftp://' && substr($txt, $pos, 9) != 'mailto://' && substr($txt, $pos, 2) != '//') {
          $new_txt .= substr($txt, 0, $pos) . $new_base_url;
        }
        else {
          $new_txt .= substr($txt, 0, $pos);
        }
        $txt = substr($txt, $pos);
      }
      $txt = $new_txt . $txt;
      $new_txt = '';
    }
    return $txt;
  }

}

==> rel_to_abs-8.x-1.0.tar.gz: rel_to_abs/src/Plugin/Filter/RelToAbs.php <==
<?php

/**
 * @file
 * Contains \Drupal\rel_to_abs\Plugin\Filter\RelToAbs.
 */

namespace Drupal\rel_to_abs\Plugin\Filter;

use Drupal\filter\FilterProcessResult;
use Drupal\filter\Plugin\FilterBase;

/**
 * Provides a filter to convert relative paths to absolute URLs.
 *
 * @Filter(
 *   id = "rel_to_abs",
 *   title = @Translation("Convert relative paths to absolute URLs"),
 *   type = Drupal\filter\Plugin\FilterInterface::TYPE_TRANSFORM_REVERSIBLE
 * )
 */
class RelToAbs extends FilterBase {

  /**
   * {@inheritdoc}
   */
  public function process($text, $langcode) {

    $base_url = \Drupal::url('<front>', array(), array(
      'absolute' => TRUE,
      'language' => \Drupal::getContainer()
        ->get('language_manager')
        ->getLanguage($langcode)
    ));

    $text = $this->absoluteUrl($text, $base_url);
    return new FilterProcessResult($text);

  }

  /**
   * Absolute url callback.
   *
   * @param string $txt
   *   Text to be parsed.
   * @param string $base_url
   *   Base url of the site to prefix.
   *
   * @return string
   *   Processed text.
   */
  public function absoluteUrl($txt, $base_url) {
    $needles = array('href="', 'src="', 'background="');
    $new_txt = '';
    if (substr($base_url, -1) != '/') {
      $base_url .= '/';
    }
    $new_base_url = $base_url;

    foreach ($needles as $needle) {
      while ($pos = strpos($txt, $needle)) {
        $pos += strlen($needle);
        if (substr($txt, $pos, 7) != 'http://' && substr($txt, $pos, 8) != 'https://' && substr($txt, $pos, 6) != 'ftp://' && substr($txt, $pos, 7) != 'mailto:' && substr($txt, $pos, 2) != '//' && substr($txt, $pos, 1) != '#') {
          $new_txt .= substr($txt, 0, $pos) . $new_base_url;
        }
        else {
          $new_txt .= substr($txt, 0, $pos);
        }
        $txt = substr($txt, $pos);
      }
      $txt = $new_txt . $txt;
      $new_txt = '';
    }
    return $txt;
  }

}
